@@ -483,6 +483,15 @@ struct Opt {
     #[structopt(long = "--base64-text")]
     pub ws_text_base64: bool,
 
+    /// Close connection with a status code.
+    #[structopt(long = "--close-status-code")]
+    pub close_status_code: Option<u16>,
+
+    /// Close connection with a reason message. This option only takes effect if
+    /// --close-status-code option is provided as well.
+    #[structopt(long = "--close-reason")]
+    pub close_reason: Option<String>,
+
     /// [A] On UNIX, set stdin and stdout to nonblocking mode instead of spawning a thread.
     /// This should improve performance, but may break other programs running on the same console.
     #[structopt(long = "--async-stdio")]
@@ -511,6 +520,21 @@ struct Opt {
     /// Print measured round-trip-time to stderr after each received WebSocket pong.
     #[structopt(long = "print-ping-rtts")]
     pub print_ping_rtts: bool,
+
+    /// [A] Specify encryption/decryption key for `crypto:` specifier. Requires `base64:`, `file:` or `pwd:` prefix.
+    #[cfg(feature = "crypto_peer")]
+    #[structopt(long = "crypto-key", parse(try_from_str = "websocat::crypto_peer::interpret_opt"))]
+    pub crypto_key: Option<[u8; 32]>,
+
+    /// [A] Swap encryption and decryption operations in `crypto:` specifier - encrypt on read, decrypto on write.
+    #[cfg(feature = "crypto_peer")]
+    #[structopt(long = "crypto-reverse")]
+    pub crypto_reverse: bool,
+
+    /// Expose Prometheus metrics on specified IP address and port in addition to running usual Websocat session
+    #[cfg(feature = "prometheus_peer")]
+    #[structopt(long = "prometheus")]
+    pub prometheus: Option<SocketAddr>,
 }
 
 // TODO: make it byte-oriented/OsStr?
@@ -743,6 +767,7 @@ fn run() -> Result<()> {
             no_auto_linemode
             buffer_size
             linemode_zero_terminated
+            broadcast_queue_len
             restrict_uri
             serve_static_files
             exec_set_env
@@ -768,6 +793,8 @@ fn run() -> Result<()> {
             ws_binary_prefix
             ws_binary_base64
             ws_text_base64
+            close_status_code
+            close_reason
             asyncstdio
             foreachmsg_wait_reads
             announce_listens
@@ -782,6 +809,19 @@ fn run() -> Result<()> {
                 tls_insecure
             }
         }
+        #[cfg(feature = "crypto_peer")]
+        {
+            opts! {
+                crypto_key
+                crypto_reverse
+            }
+        }
+        #[cfg(feature = "prometheus_peer")]
+        {
+            opts! {
+                prometheus
+            }
+        }
     };
 
     if let Some(ba) = cmd.basic_auth {
