@@ -89,6 +89,8 @@ pub struct Options {
     pub ws_binary_prefix: Option<String>,
     pub ws_binary_base64: bool,
     pub ws_text_base64: bool,
+    pub close_status_code: Option<u16>,
+    pub close_reason: Option<String>,
 
     /// Only affects linter
     pub asyncstdio: bool,
@@ -97,4 +99,12 @@ pub struct Options {
     pub announce_listens: bool,
     pub timestamp_monotonic: bool,
     pub print_ping_rtts: bool,
+
+    #[cfg(feature = "crypto_peer")]
+    pub crypto_key: Option<[u8; 32]>,
+    #[cfg(feature = "crypto_peer")]
+    pub crypto_reverse: bool,
+
+    #[cfg(feature = "prometheus_peer")]
+    pub prometheus: Option<SocketAddr>,
 }
